/* mkdocs */
[data-md-color-scheme="default"] {
  --md-primary-fg-color: #67b346;
}

[data-md-color-scheme="slate"] {
  --md-primary-fg-color: #4a8a30;
}

/* mkdocstrings */
div.doc-contents:not(.first) {
  padding-left: 25px;
  border-left: 4px solid rgba(230, 230, 230);
  margin-bottom: 80px;
}

.md-typeset h2 {
  font-weight: 400;
}

/* Compact enum/attribute styling */
.doc-object.doc-attribute {
  margin-bottom: 0.5em;
}

.doc-object.doc-attribute h3.doc-heading {
  margin: 0.5em 0 0.25em 0;
}

.doc-object.doc-attribute .doc-contents {
  margin-bottom: 0;
  padding-bottom: 0;
}

/* Hide attribute labels */
.doc-label-class-attribute,
.doc-label-instance-attribute {
  display: none;
}
