"""Batch API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.
"""

{% for module in modules %}
from meraki_client._api.batch.{{ module.snake_name }} import ActionBatch{{ module.class_name }}
{% endfor %}


class Batch:
    """Batch class."""

    def __init__(self) -> None:
{% for module in modules %}
        self.{{ module.attr_name }} = ActionBatch{{ module.class_name }}()
{% endfor %}
