"""Tests for appliance API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_device_appliance_dhcp_subnets(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_appliance_dhcp_subnets endpoint."""
    with skip_on_unsupported():
        client.appliance.get_device_appliance_dhcp_subnets(serial=device_serial)


def test_get_device_appliance_performance(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_appliance_performance endpoint."""
    with skip_on_unsupported():
        client.appliance.get_device_appliance_performance(serial=device_serial)


def test_get_device_appliance_prefixes_delegated(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_appliance_prefixes_delegated endpoint."""
    with skip_on_unsupported():
        client.appliance.get_device_appliance_prefixes_delegated(serial=device_serial)


def test_get_device_appliance_prefixes_delegated_vlan_assignments(
    client: MerakiClient, device_serial: str
) -> None:
    """Test get_device_appliance_prefixes_delegated_vlan_assignments endpoint."""
    with skip_on_unsupported():
        client.appliance.get_device_appliance_prefixes_delegated_vlan_assignments(
            serial=device_serial
        )


def test_get_device_appliance_radio_settings(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_appliance_radio_settings endpoint."""
    with skip_on_unsupported():
        client.appliance.get_device_appliance_radio_settings(serial=device_serial)


def test_get_device_appliance_uplinks_settings(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_appliance_uplinks_settings endpoint."""
    with skip_on_unsupported():
        client.appliance.get_device_appliance_uplinks_settings(serial=device_serial)


def test_get_network_appliance_connectivity_monitoring_destinations(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_connectivity_monitoring_destinations endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_connectivity_monitoring_destinations(
            network_id=network_id
        )


def test_get_network_appliance_content_filtering(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_content_filtering endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_content_filtering(network_id=network_id)


def test_get_network_appliance_content_filtering_categories(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_content_filtering_categories endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_content_filtering_categories(network_id=network_id)


def test_get_network_appliance_firewall_cellular_firewall_rules(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_firewall_cellular_firewall_rules endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_firewall_cellular_firewall_rules(
            network_id=network_id
        )


def test_get_network_appliance_firewall_firewalled_services(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_firewall_firewalled_services endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_firewall_firewalled_services(network_id=network_id)


def test_get_network_appliance_firewall_inbound_cellular_firewall_rules(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_firewall_inbound_cellular_firewall_rules endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_firewall_inbound_cellular_firewall_rules(
            network_id=network_id
        )


def test_get_network_appliance_firewall_inbound_firewall_rules(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_firewall_inbound_firewall_rules endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_firewall_inbound_firewall_rules(
            network_id=network_id
        )


def test_get_network_appliance_firewall_l3_firewall_rules(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_firewall_l3_firewall_rules endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_firewall_l3_firewall_rules(network_id=network_id)


def test_get_network_appliance_firewall_l7_firewall_rules(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_firewall_l7_firewall_rules endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_firewall_l7_firewall_rules(network_id=network_id)


def test_get_network_appliance_firewall_l7_firewall_rules_application_categories(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_firewall_l7_firewall_rules_application_categories endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_firewall_l7_firewall_rules_application_categories(
            network_id=network_id
        )


def test_get_network_appliance_firewall_one_to_many_nat_rules(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_firewall_one_to_many_nat_rules endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_firewall_one_to_many_nat_rules(network_id=network_id)


def test_get_network_appliance_firewall_one_to_one_nat_rules(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_firewall_one_to_one_nat_rules endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_firewall_one_to_one_nat_rules(network_id=network_id)


def test_get_network_appliance_firewall_port_forwarding_rules(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_firewall_port_forwarding_rules endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_firewall_port_forwarding_rules(network_id=network_id)


def test_get_network_appliance_firewall_settings(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_firewall_settings endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_firewall_settings(network_id=network_id)


def test_get_network_appliance_ports(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_ports endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_ports(network_id=network_id)


def test_get_network_appliance_prefixes_delegated_statics(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_prefixes_delegated_statics endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_prefixes_delegated_statics(network_id=network_id)


def test_get_network_appliance_rf_profiles(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_rf_profiles endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_rf_profiles(network_id=network_id)


def test_get_network_appliance_security_events(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_security_events endpoint."""
    with skip_on_unsupported():
        result = client.appliance.get_network_appliance_security_events(
            network_id=network_id
        ).collect()
    assert isinstance(result, list)


def test_get_network_appliance_security_intrusion(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_security_intrusion endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_security_intrusion(network_id=network_id)


def test_get_network_appliance_security_malware(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_security_malware endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_security_malware(network_id=network_id)


def test_get_network_appliance_settings(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_settings endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_settings(network_id=network_id)


def test_get_network_appliance_single_lan(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_single_lan endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_single_lan(network_id=network_id)


def test_get_network_appliance_ssids(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_ssids endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_ssids(network_id=network_id)


def test_get_network_appliance_static_routes(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_static_routes endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_static_routes(network_id=network_id)


def test_get_network_appliance_traffic_shaping(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_traffic_shaping endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_traffic_shaping(network_id=network_id)


def test_get_network_appliance_traffic_shaping_custom_performance_classes(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_traffic_shaping_custom_performance_classes endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_traffic_shaping_custom_performance_classes(
            network_id=network_id
        )


def test_get_network_appliance_traffic_shaping_rules(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_traffic_shaping_rules endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_traffic_shaping_rules(network_id=network_id)


def test_get_network_appliance_traffic_shaping_uplink_bandwidth(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_traffic_shaping_uplink_bandwidth endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_traffic_shaping_uplink_bandwidth(
            network_id=network_id
        )


def test_get_network_appliance_traffic_shaping_uplink_selection(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_appliance_traffic_shaping_uplink_selection endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_traffic_shaping_uplink_selection(
            network_id=network_id
        )


def test_get_network_appliance_uplinks_usage_history(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_uplinks_usage_history endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_uplinks_usage_history(network_id=network_id)


def test_get_network_appliance_vlans(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_vlans endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_vlans(network_id=network_id)


def test_get_network_appliance_vlans_settings(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_vlans_settings endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_vlans_settings(network_id=network_id)


def test_get_network_appliance_vpn_bgp(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_vpn_bgp endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_vpn_bgp(network_id=network_id)


def test_get_network_appliance_vpn_site_to_site_vpn(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_vpn_site_to_site_vpn endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_vpn_site_to_site_vpn(network_id=network_id)


def test_get_network_appliance_warm_spare(client: MerakiClient, network_id: str) -> None:
    """Test get_network_appliance_warm_spare endpoint."""
    with skip_on_unsupported():
        client.appliance.get_network_appliance_warm_spare(network_id=network_id)


def test_get_organization_appliance_dns_local_profiles(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_dns_local_profiles endpoint."""
    with skip_on_unsupported():
        client.appliance.get_organization_appliance_dns_local_profiles(
            organization_id=organization_id
        )


def test_get_organization_appliance_dns_local_profiles_assignments(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_dns_local_profiles_assignments endpoint."""
    with skip_on_unsupported():
        client.appliance.get_organization_appliance_dns_local_profiles_assignments(
            organization_id=organization_id
        )


def test_get_organization_appliance_dns_local_records(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_dns_local_records endpoint."""
    with skip_on_unsupported():
        client.appliance.get_organization_appliance_dns_local_records(
            organization_id=organization_id
        )


def test_get_organization_appliance_dns_split_profiles(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_dns_split_profiles endpoint."""
    with skip_on_unsupported():
        client.appliance.get_organization_appliance_dns_split_profiles(
            organization_id=organization_id
        )


def test_get_organization_appliance_dns_split_profiles_assignments(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_dns_split_profiles_assignments endpoint."""
    with skip_on_unsupported():
        client.appliance.get_organization_appliance_dns_split_profiles_assignments(
            organization_id=organization_id
        )


def test_get_organization_appliance_firewall_multicast_forwarding_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_firewall_multicast_forwarding_by_network endpoint."""
    with skip_on_unsupported():
        result = (
            client.appliance.get_organization_appliance_firewall_multicast_forwarding_by_network(
                organization_id=organization_id
            ).collect()
        )
    assert isinstance(result, list)


def test_get_organization_appliance_security_events(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_security_events endpoint."""
    with skip_on_unsupported():
        result = client.appliance.get_organization_appliance_security_events(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_appliance_security_intrusion(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_security_intrusion endpoint."""
    with skip_on_unsupported():
        client.appliance.get_organization_appliance_security_intrusion(
            organization_id=organization_id
        )


def test_get_organization_appliance_traffic_shaping_vpn_exclusions_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_traffic_shaping_vpn_exclusions_by_network endpoint."""
    with skip_on_unsupported():
        result = (
            client.appliance.get_organization_appliance_traffic_shaping_vpn_exclusions_by_network(
                organization_id=organization_id
            ).collect()
        )
    assert isinstance(result, list)


def test_get_organization_appliance_uplink_statuses(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_uplink_statuses endpoint."""
    with skip_on_unsupported():
        result = client.appliance.get_organization_appliance_uplink_statuses(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_appliance_uplinks_statuses_overview(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_uplinks_statuses_overview endpoint."""
    with skip_on_unsupported():
        client.appliance.get_organization_appliance_uplinks_statuses_overview(
            organization_id=organization_id
        )


def test_get_organization_appliance_uplinks_usage_by_network(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_uplinks_usage_by_network endpoint."""
    with skip_on_unsupported():
        client.appliance.get_organization_appliance_uplinks_usage_by_network(
            organization_id=organization_id
        )


def test_get_organization_appliance_vpn_site_to_site_ipsec_peers_slas(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_vpn_site_to_site_ipsec_peers_slas endpoint."""
    with skip_on_unsupported():
        client.appliance.get_organization_appliance_vpn_site_to_site_ipsec_peers_slas(
            organization_id=organization_id
        )


def test_get_organization_appliance_vpn_stats(client: MerakiClient, organization_id: str) -> None:
    """Test get_organization_appliance_vpn_stats endpoint."""
    with skip_on_unsupported():
        result = client.appliance.get_organization_appliance_vpn_stats(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_appliance_vpn_statuses(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_vpn_statuses endpoint."""
    with skip_on_unsupported():
        result = client.appliance.get_organization_appliance_vpn_statuses(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_appliance_vpn_third_party_vpn_peers(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_vpn_third_party_vpn_peers endpoint."""
    with skip_on_unsupported():
        client.appliance.get_organization_appliance_vpn_third_party_vpn_peers(
            organization_id=organization_id
        )


def test_get_organization_appliance_vpn_vpn_firewall_rules(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_appliance_vpn_vpn_firewall_rules endpoint."""
    with skip_on_unsupported():
        client.appliance.get_organization_appliance_vpn_vpn_firewall_rules(
            organization_id=organization_id
        )
