"""Tests for administered API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_administered_identities_me(client: MerakiClient) -> None:
    """Test get_administered_identities_me endpoint."""
    with skip_on_unsupported():
        client.administered.get_administered_identities_me()


def test_get_administered_identities_me_api_keys(client: MerakiClient) -> None:
    """Test get_administered_identities_me_api_keys endpoint."""
    with skip_on_unsupported():
        client.administered.get_administered_identities_me_api_keys()
