"""Response schemas for {{ scope }} endpoints.

This module is automatically @generated from the Meraki API specification.
Do not edit this file manually.
"""

from __future__ import annotations

from datetime import date, datetime, time
from typing import Any

from pydantic import Field, RootModel

from meraki_client.schemas._base import _BaseSchema

{% for class_def in schema_definitions %}
{{ class_def }}
{% endfor %}
