"""Response schemas for the Meraki API.

This module is automatically @generated from the Meraki API specification.
Do not edit this file manually.
"""

from meraki_client.schemas._base import DictResponse

{% for scope, class_names in exports.items() %}
from meraki_client.schemas._{{ scope }} import (
{% for class_name in class_names %}
    {{ class_name }},
{% endfor %}
)

{% endfor %}
__all__ = [
{% for class_name in all_schemas %}
    "{{ class_name }}",
{% endfor %}
    "DictResponse",
]
