"""Response schemas for the Meraki API.

This module is automatically @generated from the Meraki API specification.
Do not edit this file manually.
"""

from typing import Any

from pydantic import BaseModel, ConfigDict, RootModel


class _BaseSchema(BaseModel):
    """Base class for all response schemas."""

    model_config = ConfigDict(extra="allow", populate_by_name=True)


class DictResponse(RootModel):
    """Response schema for responses that are missing type information in the OpenAPI spec."""

    root: dict[str, Any]
