"""ActionBatch{{ class_name }} API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

import urllib.parse
from typing import Any, Literal

{% if enum_type_aliases %}
from meraki_client.types import (
{% for type_alias in enum_type_aliases %}
    {{ type_alias }},
{% endfor %}
)
{% endif %}

from meraki_client.schemas import (
    CreateOrganizationActionBatchActionsItem,
    DictResponse,
{% for schema in schemas_used %}
    {{ schema }},
{% endfor %}
)


class ActionBatch{{ class_name }}:
    """ActionBatch{{ class_name }} class."""

    def __init__(self) -> None:
        pass
