"""Tests for campusGateway API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_organization_campus_gateway_clusters(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_campus_gateway_clusters endpoint."""
    with skip_on_unsupported():
        result = client.campus_gateway.get_organization_campus_gateway_clusters(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)


def test_get_organization_campus_gateway_devices_uplinks_local_overrides_by_device(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_campus_gateway_devices_uplinks_local_overrides_by_device endpoint."""
    with skip_on_unsupported():
        result = client.campus_gateway.get_organization_campus_gateway_devices_uplinks_local_overrides_by_device(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)
