"""ActionBatchSpaces API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

import urllib.parse

from meraki_client.schemas import (
    CreateOrganizationActionBatchActionsItem,
)


class ActionBatchSpaces:
    """ActionBatchSpaces class."""

    def __init__(self) -> None:
        pass

    def remove_organization_spaces_integration(
        self, organization_id: str
    ) -> CreateOrganizationActionBatchActionsItem:
        """Remove the Spaces integration from Meraki.

        [API documentation: removeOrganizationSpacesIntegration](https://developer.cisco.com/meraki/api-v1/#!remove-organization-spaces-integration)

        Args:
            organization_id: Organization ID.

        """
        organization_id = urllib.parse.quote(str(organization_id), safe="")
        path = f"/organizations/{organization_id}/spaces/integration/remove"

        return CreateOrganizationActionBatchActionsItem(
            resource=path,
            operation="integration",
        )
