"""Tests for cellularGateway API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_device_cellular_gateway_lan(client: MerakiClient, device_serial: str) -> None:
    """Test get_device_cellular_gateway_lan endpoint."""
    with skip_on_unsupported():
        client.cellular_gateway.get_device_cellular_gateway_lan(serial=device_serial)


def test_get_device_cellular_gateway_port_forwarding_rules(
    client: MerakiClient, device_serial: str
) -> None:
    """Test get_device_cellular_gateway_port_forwarding_rules endpoint."""
    with skip_on_unsupported():
        client.cellular_gateway.get_device_cellular_gateway_port_forwarding_rules(
            serial=device_serial
        )


def test_get_network_cellular_gateway_connectivity_monitoring_destinations(
    client: MerakiClient, network_id: str
) -> None:
    """Test get_network_cellular_gateway_connectivity_monitoring_destinations endpoint."""
    with skip_on_unsupported():
        client.cellular_gateway.get_network_cellular_gateway_connectivity_monitoring_destinations(
            network_id=network_id
        )


def test_get_network_cellular_gateway_dhcp(client: MerakiClient, network_id: str) -> None:
    """Test get_network_cellular_gateway_dhcp endpoint."""
    with skip_on_unsupported():
        client.cellular_gateway.get_network_cellular_gateway_dhcp(network_id=network_id)


def test_get_network_cellular_gateway_subnet_pool(client: MerakiClient, network_id: str) -> None:
    """Test get_network_cellular_gateway_subnet_pool endpoint."""
    with skip_on_unsupported():
        client.cellular_gateway.get_network_cellular_gateway_subnet_pool(network_id=network_id)


def test_get_network_cellular_gateway_uplink(client: MerakiClient, network_id: str) -> None:
    """Test get_network_cellular_gateway_uplink endpoint."""
    with skip_on_unsupported():
        client.cellular_gateway.get_network_cellular_gateway_uplink(network_id=network_id)


def test_get_organization_cellular_gateway_esims_inventory(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_cellular_gateway_esims_inventory endpoint."""
    with skip_on_unsupported():
        client.cellular_gateway.get_organization_cellular_gateway_esims_inventory(
            organization_id=organization_id
        )


def test_get_organization_cellular_gateway_esims_service_providers(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_cellular_gateway_esims_service_providers endpoint."""
    with skip_on_unsupported():
        client.cellular_gateway.get_organization_cellular_gateway_esims_service_providers(
            organization_id=organization_id
        )


def test_get_organization_cellular_gateway_esims_service_providers_accounts(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_cellular_gateway_esims_service_providers_accounts endpoint."""
    with skip_on_unsupported():
        client.cellular_gateway.get_organization_cellular_gateway_esims_service_providers_accounts(
            organization_id=organization_id
        )


def test_get_organization_cellular_gateway_uplink_statuses(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_cellular_gateway_uplink_statuses endpoint."""
    with skip_on_unsupported():
        result = client.cellular_gateway.get_organization_cellular_gateway_uplink_statuses(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)
