"""Tests for licensing API endpoints.

This file is automatically @generated from the Meraki API specification.
Do not edit this file manually.

"""

from meraki_client import MerakiClient
from tests.generated.conftest import skip_on_unsupported


def test_get_administered_licensing_subscription_entitlements(client: MerakiClient) -> None:
    """Test get_administered_licensing_subscription_entitlements endpoint."""
    with skip_on_unsupported():
        client.licensing.get_administered_licensing_subscription_entitlements()


def test_get_organization_licensing_coterm_licenses(
    client: MerakiClient, organization_id: str
) -> None:
    """Test get_organization_licensing_coterm_licenses endpoint."""
    with skip_on_unsupported():
        result = client.licensing.get_organization_licensing_coterm_licenses(
            organization_id=organization_id
        ).collect()
    assert isinstance(result, list)
